@@ -1,11 +1,11 @@
 import os
 from PIL import Image
 import numpy
-from torch import LongTensor, FloatTensor
+from torch import LongTensor
 import torch
 import json
 import requests
-from typing import Callable, Tuple, Iterator
+from typing import Iterator
 torch.set_grad_enabled(False)
 torch.set_num_threads(os.cpu_count())
 
@@ -165,9 +165,11 @@ class MinDalle:
         seed: int,
         grid_size: int,
         log2_mid_count: int,
+        log2_k: int = 6,
         log2_supercondition_factor: int = 3,
         is_verbose: bool = False
     ) -> Iterator[Image.Image]:
+        assert(log2_mid_count in range(5))
         if is_verbose: print("tokenizing text")
         tokens = self.tokenizer.tokenize(text, is_verbose=is_verbose)
         if is_verbose: print("text tokens", tokens)
@@ -201,6 +203,7 @@ class MinDalle:
                 print('sampling row {} of {}'.format(row_index + 1, row_count))
             attention_state, image_tokens = self.decoder.decode_row(
                 row_index,
+                log2_k,
                 log2_supercondition_factor,
                 encoder_state,
                 attention_mask,
@@ -218,6 +221,7 @@ class MinDalle:
         text: str,
         seed: int = -1,
         grid_size: int = 1,
+        log2_k: int = 6,
         log2_supercondition_factor: int = 3,
         is_verbose: bool = False
     ) -> Image.Image:
@@ -227,6 +231,7 @@ class MinDalle:
             seed,
             grid_size,
             log2_mid_count,
+            log2_k,
             log2_supercondition_factor,
             is_verbose
         )
